@@ -26,4 +26,4 @@ class NodeException(str):
         return f"Exception({self.value})"
 
 
-EventValue = Union[Tuple[Any], NodeException]
+EventValue = Union[Tuple[Any, ...], NodeException]
